﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections;
using Infragistics.Olap.FlatData;
using Infragistics.Olap;
using Infragistics.Controls.Grids;

namespace SilverlightApplication8
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            BuildPivotGrid();
        }

        private void BuildPivotGrid()
        {
            #region Create FlatDataSource

            FlatDataSource flatDataSource = new FlatDataSource()
            {
                ItemsSource = SampleDataGenerator.GenerateSales(500),
                Cube = DataSourceBase.GenerateInitialCube("Sale"),
                Rows = DataSourceBase.GenerateInitialItems("[Product_Internal].[Product]"),
                Columns = DataSourceBase.GenerateInitialItems("[Seller].[Seller]"),
                Measures = DataSourceBase.GenerateInitialItems("NumberOfUnits")
            };

            #endregion

            #region Create CubeSettings

            CubeMetadata cubeMetadata = new CubeMetadata();
            cubeMetadata.DisplayName = "Report";

            cubeMetadata.DataTypeFullName = typeof(Sale).FullName;

            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Product_Internal",
                DisplayName = "Product",
            });

            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Seller",
                DisplayName = "Seller"
            });

            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Date",
                DisplayName = "Date"
            });

            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "NumberOfUnits",
                DisplayName = "Number Of Units",
                DimensionType = DimensionType.Measure
            });

            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "City",
                DisplayName = "City"
            });

            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "AmountOfSale",
                DisplayName = "$ Amount of Sale",
                DimensionType = DimensionType.Measure
            });

            flatDataSource.CubesSettings.Add(cubeMetadata);

            #endregion

            #region Create HierarchyDescriptors

            HierarchyDescriptor productHierarchy = new HierarchyDescriptor("Product");
            productHierarchy.SourcePropertyName = "Product_Internal";

            productHierarchy.LevelDescriptors.Add(new HierarchyLevelDescriptor
            {
                LevelName = "Product Name",
                LevelExpressionPath = "Product_Internal.Full___Name"
            });

            flatDataSource.HierarchyDescriptors.Add(productHierarchy);

            #endregion

            this.xamPivotGrid1.DataSource = flatDataSource;
            this.xamPivotDataSelector1.DataSource = flatDataSource;
        }

        private void expandCells()
        {
            foreach (PivotHeaderCell cell in xamPivotGrid1.GridLayout.RowHeaderCells)
            {


                if (cell.IsToggleVisible && cell.IsExpanded == false)
                {



                    cell.IsExpanded = true;
               //     xamPivotGrid1.UpdateLayout();
                     return;


                }


            }

        }
        private void expand_Click(object sender, RoutedEventArgs e)
        {

            expandCells();


        }

        private void xamPivotGrid1_LayoutLoaded(object sender, EventArgs e)
        {
            expandCells();
        }
    }

    public class SampleDataGenerator
    {
        private static String[] Products;
        private static String[] SellerNames;
        private static String[] Cities;

        private static Random random = new Random();

        public static IEnumerable GenerateSales(int numberOfSales)
        {
            SampleDataGenerator.Products = new string[] { "Zumba", "Lets Draw", "Monster Tale", "Cooking Mama", "Crafting Mama" };// PivotGridStrings.XPG_Data_ProductCategories.Split(';');
            SampleDataGenerator.SellerNames = new string[] { "Walmart", "Gamestop", "Amazon", "BestBuy" };//PivotGridStrings.XPG_Data_SellerNames.Split(';');
            SampleDataGenerator.Cities = new string[] { "NYC", "Los Angeles", "Chicago" };//PivotGridStrings.XPG_Data_Cities.Split(';');

            List<Sale> Sales = new List<Sale>();
            for (double i = 0; i < numberOfSales; i++)
            {
                Sale sale = new Sale();
                sale.Date = GetRandomDate();
                sale.Product_Internal = GerRandomProduct();
                sale.NumberOfUnits = GetRandomNumUnits();
                sale.Seller = GetRandomSeller();
                Sales.Add(sale);
            }
            return Sales;
        }

        #region Get Random Objects
        private static Seller GetRandomSeller()
        {
            return new Seller()
            {
                City = GetRandomCity(),
                Name = GetRandomSellerName()
            };
        }

        private static string GetRandomSellerName()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return SampleDataGenerator.SellerNames[a.Next(SampleDataGenerator.SellerNames.Length)];
        }

        private static string GetRandomCity()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return SampleDataGenerator.Cities[a.Next(SampleDataGenerator.Cities.Length)];
        }

        private static int GetRandomNumUnits()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return a.Next(1, 500);
        }

        private static Product GerRandomProduct()
        {
            return new Product()
            {
                Full___Name = GetRandomProductName(),
                Desc = "ABCDEFGHIJKL",
                Price = GetRandomPrice()
            };
        }

        private static double GetRandomPrice()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return a.NextDouble() * 100;
        }

        private static string GetRandomProductName()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return SampleDataGenerator.Products[a.Next(SampleDataGenerator.Products.Length)];
        }

        private static DateTime GetRandomDate()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            int day = a.Next(1, 28);
            int month = a.Next(1, 12);
            int year = a.Next(2006, 2010);
            return new DateTime(year, month, day);
        }
        #endregion Get Random Objects
    }

    public class Sale
    {
        public Product Product_Internal { get; set; }
        public Seller Seller { get; set; }
        public DateTime Date { get; set; }
        public string City
        {
            get { return Seller.City; }
            set { Seller.City = value; }
        }

        public int NumberOfUnits { get; set; }
        public double AmountOfSale
        {
            get { return Product_Internal.Price * NumberOfUnits; }
            set { Product_Internal.Price = value / NumberOfUnits; }
        }
    }

    public class Product
    {
        public string Full___Name { get; set; }
        public string Desc { get; set; }
        public double Price { get; set; }

        public override string ToString()
        {
            return Full___Name;
        }
    }

    public class Seller
    {
        public string Name { get; set; }
        public string City { get; set; }

        public override string ToString()
        {
            return Name;
        }
    }

}
